@@ -29,6 +29,8 @@ def get_numeric_df_by_column(target_df: pd.DataFrame, target_column_list: list =
         column_list = target_column_list
     if ignore_column_list is not None:
         for item in ignore_column_list:
+            if item not in column_list:
+                continue
             column_list.remove(item)
     for column in column_list:
         # s = df[column].str.extract(r'(-?[0-9]*([\.][0-9]+)?)', expand=True)[0]
@@ -93,8 +95,13 @@ def request_post_json(api_url: str, headers: dict, request_param: dict):
             break
     try:
         dict_result = response.json()['data']
-    except:
-        return None
+    except Exception:
+        try:
+            dict_result = response.json()['text']
+        except Exception:
+            return None
+        else:
+            return dict_result
     else:
         return dict_result
 
